@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h,v 1.68 2004/08/28 23:24:23 mbarbon Exp $
-// Copyright:   (c) 2000-2003 Mattia Barbon
+// RCS-ID:      $Id: helpers.h,v 1.70 2005/01/03 21:06:40 mbarbon Exp $
+// Copyright:   (c) 2000-2004 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -319,7 +319,7 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
 
 #define INIT_PLI_HELPERS( name ) \
   SV* wxpli_tmp = get_sv( "Wx::_exports", 1 ); \
-  wxPliHelpers* name = (wxPliHelpers*)(void*)SvIV( wxpli_tmp ); \
+  wxPliHelpers* name = INT2PTR( wxPliHelpers*, SvIV( wxpli_tmp ) ); \
   wxPli_sv_2_object = name->m_wxPli_sv_2_object; \
   wxPli_evthandler_2_sv = name->m_wxPli_evthandler_2_sv; \
   wxPli_object_2_sv = name->m_wxPli_object_2_sv; \
