@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     05/06/2003
-## RCS-ID:      $Id: wxGridCER.pm,v 1.4 2005/11/22 22:47:39 mbarbon Exp $
-## Copyright:   (c) 2003, 2005 Mattia Barbon
+## RCS-ID:      $Id: wxGridCER.pm,v 1.1 2003/06/05 17:28:10 mbarbon Exp $
+## Copyright:   (c) 2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -126,9 +126,7 @@ sub new {
 sub Create {
   my( $self, $parent, $id, $evthandler ) = @_;
 
-  $self->SetControl( Wx::TextCtrl->new( $parent, $id, 'Default value', [-1,-1], [-1,-1], Wx::wxTE_PROCESS_TAB ) );
-
-  $self->GetControl->PushEventHandler( $evthandler );
+  $self->{text_ctrl} = Wx::TextCtrl->new( $parent, $id, 'Default value' );
 
   Wx::LogMessage( 'Create called' );
 }
@@ -136,14 +134,13 @@ sub Create {
 sub Destroy {
   my $self = shift;
 
-  $self->GetControl->Destroy if $self->GetControl;
-  $self->SetControl( undef );
+  $self->{text_ctrl}->Destroy if $self->{text_ctrl};
 }
 
 sub SetSize {
   my( $self, $size ) = @_;
 
-  $self->GetControl->SetSize( $size );
+  $self->{text_ctrl}->SetSize( $size );
 
   Wx::LogMessage( 'SetSize called' );
 }
@@ -151,7 +148,7 @@ sub SetSize {
 sub Show {
   my( $self, $show, $attr ) = @_;
 
-  $self->GetControl->Show( $show );
+  $self->{text_ctrl}->Show( $show );
 
   Wx::LogMessage( 'Show called' );
 }
@@ -159,16 +156,13 @@ sub Show {
 sub EndEdit {
   my( $self, $row, $col, $grid ) = @_;
 
-  my $value = '>> ' . $self->GetControl->GetValue . ' <<';
+  my $value = '>> ' . $self->{text_ctrl}->GetValue . ' <<';
   my $oldValue = $grid->GetCellValue( $row, $col );
 
   my $changed =  $value ne $oldValue;
 
   if( $changed ) { $grid->SetCellValue( $row, $col, $value ) }
 
-  $self->GetControl->Destroy;
-  $self->SetControl( undef );
-
   Wx::LogMessage( 'EndEdit called' );
 
   return $changed;
