@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        Tests_Helper.PL
+## Name:        t/Tests_Helper.pm
 ## Purpose:     some test helper functions
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:      2/ 6/2001
-## RCS-ID:      
-## Copyright:   (c) 2001 Mattia Barbon
+## Created:     02/06/2001
+## RCS-ID:      $Id: Tests_Helper.pm,v 1.5 2004/04/10 20:36:57 mbarbon Exp $
+## Copyright:   (c) 2001-2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -13,6 +13,7 @@
 package Tests_Helper;
 
 use strict;
+use Wx;
 require Exporter;
 
 use Test::More ();
@@ -26,13 +27,26 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK);
 
 @EXPORT_OK = qw(test_inheritance test_inheritance_all
                 test_inheritance_start test_inheritance_end
-                test_app test_frame app_timeout);
+                test_app test_frame app_timeout in_frame);
 
 %EXPORT_TAGS =
   ( inheritance => [ qw(test_inheritance test_inheritance_all
                         test_inheritance_start test_inheritance_end) ],
   );
 
+sub in_frame($) {
+  my $callback = shift;
+  my $sub = sub {
+    my $frame = Tests_Helper_Frame->new( $callback );
+
+    $frame->Show( 1 );
+  };
+
+  test_app( $sub );
+
+  Wx::wxTheApp->MainLoop;
+}
+
 sub app_timeout($) {
   test_app( sub {
               my $frame = Wx::Frame->new( undef, -1, 'test' );
@@ -44,7 +58,7 @@ sub app_timeout($) {
                                     } );
 
               $timer->Start( 500, 1 );
-              Wx::WakeUpIdle;
+              Wx::WakeUpIdle();
               $frame->Show( 1 );
             } );
 }
@@ -106,7 +120,7 @@ sub test_inheritance {
   COMPARE: while ( @ci ) {
       my( $c_class ) = shift @ci;
       next if $c_class =~ m/Wx::Generic(?:ListCtrl|ImageList)/;
-      next if $c_class =~ m/(?:Base|GTK)$/;
+      next if $c_class =~ m/(?:Base|GTK|X11)$/;
       next if $c_class =~ m/StatusBar/; #FIXME// ad hoc
       next if $c_class eq 'Wx::Object';
       my( $p_class );
@@ -200,6 +214,29 @@ sub OnInit {
   return 1;
 }
 
+package Tests_Helper_Frame;
+
+use base 'Wx::Frame';
+
+sub new {
+  my $ref = shift;
+  my $callback = shift;
+  my $self = $ref->SUPER::new( undef, -1, "Test Frame" );
+  my $timer = Wx::Timer->new( $self );
+
+  Wx::Event::EVT_TIMER( $self, -1, sub {
+                            &$callback( $self, $_[1] );
+                            $self->Destroy;
+                            Wx::wxTheApp()->ExitMainLoop;
+                            Wx::WakeUpIdle();
+                        } );
+
+  $timer->Start( 500, 1 );
+  Wx::WakeUpIdle();
+
+  return $self;
+}
+
 1;
 
 # Local variables: #
